Changes from v0.4 to v0.5
=========================


API Changes
-----------


New Features
------------
- Use setuptools_scm for versioning
- Modernized packaging


Performance Improvements
------------------------


Bug Fixes
---------
- Use the new Zenodo API
- Use unambiguous ComCam camera name
- Don't presume 50 degrees-of-freedom
- Don't modify self when using .with methods
